SiQt
====

|Documentation| |Build Status|

Convenience tools for building PyQt5 / PySide2 based GUI applications.


See the documentation for more details: `http://siqt.readthedocs.io/en/latest/ <http://siqt.readthedocs.io/en/latest/>`_


Installation
------------

This package requires Python 3.5+ and either ``PyQt5`` or ``PySide2``.

It can be installed with,

::

    pip install SiQt


Unit tests
----------

The test suite can be run with,

::

    py.test -sv .


.. |Build Status| image:: https://travis-ci.org/symerio/SiQt.svg?branch=master
   :target: https://travis-ci.org/symerio/SiQt

.. |Documentation| image:: https://readthedocs.org/projects/siqt/badge/?version=latest
   :target: https://siqt.readthedocs.io/en/latest/?badge=latest
